/*
 *  Copyright (C) 2010 by Filip Brcic <brcha@gna.org>
 *
 *  This file is part of VukoviTray
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef VUKOVITRAY_H
#define VUKOVITRAY_H

#include <QtCore/QUrl>

#include <QtGui/QWidget>
#include <QtGui/QSystemTrayIcon>

namespace Ui
{
    class VukoviTray;
}

class QCloseEvent;
class QSettings;
class QNetworkAccessManager;
class QNetworkReply;
class QErrorMessage;

#define VERSION "1.0.2"

class VukoviTray : public QWidget
{
    Q_OBJECT

public:
    VukoviTray(QWidget *parent = 0);
    ~VukoviTray();

private slots:
    void showMessage();
    void hideWindow();
    void quitApplication();
    void startOrdersUpdate();
    void receiveOrders(QNetworkReply * reply);
    void iconActivated(QSystemTrayIcon::ActivationReason reason);
//    void detectedNewVersion(QString version);

//signals:
//    void newVersionAvailable(QString version);

protected:
    void closeEvent(QCloseEvent * event);

private:
    void setupActions();
    void createTrayIcon();
    void loadSettings();
    void saveSettings();

    Ui::VukoviTray *ui;

    QSystemTrayIcon * trayIcon;
    QSettings * settings;

    QNetworkAccessManager * networkAccessManager;

    QUrl ordersUrl;
    int updateInterval;
    int updateIntervalSecs;
    QString order;

    QUrl updateCheckUrl;
};

#endif // VUKOVITRAY_H
